@@ -61,9 +61,47 @@ class SqsClient extends AbstractApi
     /**
      * Changes the visibility timeout of a specified message in a queue to a new value. The default visibility timeout for a
      * message is 30 seconds. The minimum is 0 seconds. The maximum is 12 hours. For more information, see Visibility
-     * Timeout in the *Amazon SQS Developer Guide*.
+     * Timeout [^1] in the *Amazon SQS Developer Guide*.
+     *
+     * For example, if the default timeout for a queue is 60 seconds, 15 seconds have elapsed since you received the
+     * message, and you send a ChangeMessageVisibility call with `VisibilityTimeout` set to 10 seconds, the 10 seconds begin
+     * to count from the time that you make the `ChangeMessageVisibility` call. Thus, any attempt to change the visibility
+     * timeout or to delete that message 10 seconds after you initially change the visibility timeout (a total of 25
+     * seconds) might result in an error.
+     *
+     * An Amazon SQS message has three basic states:
+     *
+     * 1. Sent to a queue by a producer.
+     * 2. Received from the queue by a consumer.
+     * 3. Deleted from the queue.
+     *
+     * A message is considered to be *stored* after it is sent to a queue by a producer, but not yet received from the queue
+     * by a consumer (that is, between states 1 and 2). There is no limit to the number of stored messages. A message is
+     * considered to be *in flight* after it is received from a queue by a consumer, but not yet deleted from the queue
+     * (that is, between states 2 and 3). There is a limit to the number of in flight messages.
+     *
+     * Limits that apply to in flight messages are unrelated to the *unlimited* number of stored messages.
+     *
+     * For most standard queues (depending on queue traffic and message backlog), there can be a maximum of approximately
+     * 120,000 in flight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach
+     * this limit, Amazon SQS returns the `OverLimit` error message. To avoid reaching the limit, you should delete messages
+     * from the queue after they're processed. You can also increase the number of queues you use to process your messages.
+     * To request a limit increase, file a support request [^2].
+     *
+     * For FIFO queues, there can be a maximum of 20,000 in flight messages (received from a queue by a consumer, but not
+     * yet deleted from the queue). If you reach this limit, Amazon SQS returns no error messages.
+     *
+     * ! If you attempt to set the `VisibilityTimeout` to a value greater than the maximum time left, Amazon SQS returns an
+     * ! error. Amazon SQS doesn't automatically recalculate and increase the timeout to the maximum remaining time.
+     * !
+     * ! Unlike with a queue, when you change the visibility timeout for a specific message the timeout value is applied
+     * ! immediately but isn't saved in memory for that message. If you don't delete a message after it is received, the
+     * ! visibility timeout for the message reverts to the original timeout value (not to the value you set using the
+     * ! `ChangeMessageVisibility` action) the next time the message is received.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-visibility-timeout.html
+     * [^2]: https://console.aws.amazon.com/support/home#/case/create?issueType=service-limit-increase&amp;limitType=service-code-sqs
      *
-     * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-visibility-timeout.html
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ChangeMessageVisibility.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#changemessagevisibility
      *
@@ -71,7 +109,7 @@ class SqsClient extends AbstractApi
      *   QueueUrl: string,
      *   ReceiptHandle: string,
      *   VisibilityTimeout: int,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|ChangeMessageVisibilityRequest $input
      *
      * @throws MessageNotInflightException
@@ -93,13 +131,16 @@ class SqsClient extends AbstractApi
      * of the action on each message is reported individually in the response. You can send up to 10
      * `ChangeMessageVisibility` requests with each `ChangeMessageVisibilityBatch` action.
      *
+     * ! Because the batch request can result in a combination of successful and unsuccessful actions, you should check for
+     * ! batch errors even when the call returns an HTTP status code of `200`.
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ChangeMessageVisibilityBatch.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#changemessagevisibilitybatch
      *
      * @param array{
      *   QueueUrl: string,
-     *   Entries: ChangeMessageVisibilityBatchRequestEntry[],
-     *   @region?: string,
+     *   Entries: array<ChangeMessageVisibilityBatchRequestEntry|array>,
+     *   '@region'?: string|null,
      * }|ChangeMessageVisibilityBatchRequest $input
      *
      * @throws TooManyEntriesInBatchRequestException
@@ -123,6 +164,36 @@ class SqsClient extends AbstractApi
     /**
      * Creates a new standard or FIFO queue. You can pass one or more attributes in the request. Keep the following in mind:.
      *
+     * - If you don't specify the `FifoQueue` attribute, Amazon SQS creates a standard queue.
+     *
+     *   > You can't change the queue type after you create it and you can't convert an existing standard queue into a FIFO
+     *   > queue. You must either create a new FIFO queue for your application or delete your existing standard queue and
+     *   > recreate it as a FIFO queue. For more information, see Moving From a Standard Queue to a FIFO Queue [^1] in the
+     *   > *Amazon SQS Developer Guide*.
+     *
+     * - If you don't provide a value for an attribute, the queue is created with the default value for the attribute.
+     * - If you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
+     *
+     * To successfully create a new queue, you must provide a queue name that adheres to the limits related to queues [^2]
+     * and is unique within the scope of your queues.
+     *
+     * > After you create a queue, you must wait at least one second after the queue is created to be able to use the queue.
+     *
+     * To get the queue URL, use the `GetQueueUrl` action. `GetQueueUrl` requires only the `QueueName` parameter. be aware
+     * of existing queue names:
+     *
+     * - If you provide the name of an existing queue along with the exact names and values of all the queue's attributes,
+     *   `CreateQueue` returns the queue URL for the existing queue.
+     * - If the queue name, attribute names, or attribute values don't match an existing queue, `CreateQueue` returns an
+     *   error.
+     *
+     * > Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to
+     * > a role and a username [^3] in the *Amazon SQS Developer Guide*.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/FIFO-queues.html#FIFO-queues-moving
+     * [^2]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/limits-queues.html
+     * [^3]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_CreateQueue.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#createqueue
      *
@@ -130,7 +201,7 @@ class SqsClient extends AbstractApi
      *   QueueName: string,
      *   Attributes?: array<QueueAttributeName::*, string>,
      *   tags?: array<string, string>,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|CreateQueueRequest $input
      *
      * @throws QueueDeletedRecentlyException
@@ -153,13 +224,24 @@ class SqsClient extends AbstractApi
      * a queue even if a visibility timeout setting causes the message to be locked by another consumer. Amazon SQS
      * automatically deletes messages left in a queue longer than the retention period configured for the queue.
      *
+     * > The `ReceiptHandle` is associated with a *specific instance* of receiving a message. If you receive a message more
+     * > than once, the `ReceiptHandle` is different each time you receive a message. When you use the `DeleteMessage`
+     * > action, you must provide the most recently received `ReceiptHandle` for the message (otherwise, the request
+     * > succeeds, but the message will not be deleted).
+     * >
+     * > For standard queues, it is possible to receive a message even after you delete it. This might happen on rare
+     * > occasions if one of the servers which stores a copy of the message is unavailable when you send the request to
+     * > delete the message. The copy remains on the server and might be returned to you during a subsequent receive
+     * > request. You should ensure that your application is idempotent, so that receiving a message more than once does not
+     * > cause issues.
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessage.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#deletemessage
      *
      * @param array{
      *   QueueUrl: string,
      *   ReceiptHandle: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|DeleteMessageRequest $input
      *
      * @throws InvalidIdFormatException
@@ -180,13 +262,16 @@ class SqsClient extends AbstractApi
      * Deletes up to ten messages from the specified queue. This is a batch version of `DeleteMessage.` The result of the
      * action on each message is reported individually in the response.
      *
+     * ! Because the batch request can result in a combination of successful and unsuccessful actions, you should check for
+     * ! batch errors even when the call returns an HTTP status code of `200`.
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessageBatch.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#deletemessagebatch
      *
      * @param array{
      *   QueueUrl: string,
-     *   Entries: DeleteMessageBatchRequestEntry[],
-     *   @region?: string,
+     *   Entries: array<DeleteMessageBatchRequestEntry|array>,
+     *   '@region'?: string|null,
      * }|DeleteMessageBatchRequest $input
      *
      * @throws TooManyEntriesInBatchRequestException
@@ -210,12 +295,28 @@ class SqsClient extends AbstractApi
     /**
      * Deletes the queue specified by the `QueueUrl`, regardless of the queue's contents.
      *
+     * ! Be careful with the `DeleteQueue` action: When you delete a queue, any messages in the queue are no longer
+     * ! available.
+     *
+     * When you delete a queue, the deletion process takes up to 60 seconds. Requests you send involving that queue during
+     * the 60 seconds might succeed. For example, a `SendMessage` request might succeed, but after 60 seconds the queue and
+     * the message you sent no longer exist.
+     *
+     * When you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
+     *
+     * > Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to
+     * > a role and a username [^1] in the *Amazon SQS Developer Guide*.
+     * >
+     * > The delete operation uses the HTTP `GET` verb.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteQueue.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#deletequeue
      *
      * @param array{
      *   QueueUrl: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|DeleteQueueRequest $input
      */
     public function deleteQueue($input): Result
@@ -229,13 +330,17 @@ class SqsClient extends AbstractApi
     /**
      * Gets attributes for the specified queue.
      *
+     * > To determine whether a queue is FIFO [^1], you can check whether `QueueName` ends with the `.fifo` suffix.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/FIFO-queues.html
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueAttributes.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#getqueueattributes
      *
      * @param array{
      *   QueueUrl: string,
-     *   AttributeNames?: list<QueueAttributeName::*>,
-     *   @region?: string,
+     *   AttributeNames?: array<QueueAttributeName::*>,
+     *   '@region'?: string|null,
      * }|GetQueueAttributesRequest $input
      *
      * @throws InvalidAttributeNameException
@@ -253,13 +358,20 @@ class SqsClient extends AbstractApi
     /**
      * Returns the URL of an existing Amazon SQS queue.
      *
+     * To access a queue that belongs to another AWS account, use the `QueueOwnerAWSAccountId` parameter to specify the
+     * account ID of the queue's owner. The queue's owner must grant you permission to access the queue. For more
+     * information about shared queue access, see `AddPermission` or see Allow Developers to Write Messages to a Shared
+     * Queue [^1] in the *Amazon SQS Developer Guide*.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-writing-an-sqs-policy.html#write-messages-to-shared-queue
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueUrl.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#getqueueurl
      *
      * @param array{
      *   QueueName: string,
      *   QueueOwnerAWSAccountId?: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|GetQueueUrlRequest $input
      *
      * @throws QueueDoesNotExistException
@@ -279,6 +391,16 @@ class SqsClient extends AbstractApi
      * a value for the optional `QueueNamePrefix` parameter, only queues with a name that begins with the specified value
      * are returned.
      *
+     * The `listQueues` methods supports pagination. Set parameter `MaxResults` in the request to specify the maximum number
+     * of results to be returned in the response. If you do not set `MaxResults`, the response includes a maximum of 1,000
+     * results. If you set `MaxResults` and there are additional results to display, the response includes a value for
+     * `NextToken`. Use `NextToken` as a parameter in your next request to `listQueues` to receive the next page of results.
+     *
+     * > Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to
+     * > a role and a username [^1] in the *Amazon SQS Developer Guide*.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-customer-managed-policy-examples.html#grant-cross-account-permissions-to-role-and-user-name
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListQueues.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#listqueues
      *
@@ -286,7 +408,7 @@ class SqsClient extends AbstractApi
      *   QueueNamePrefix?: string,
      *   NextToken?: string,
      *   MaxResults?: int,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|ListQueuesRequest $input
      */
     public function listQueues($input = []): ListQueuesResult
@@ -298,14 +420,23 @@ class SqsClient extends AbstractApi
     }
 
     /**
-     * Deletes the messages in a queue specified by the `QueueURL` parameter.
+     * Deletes available messages in a queue (including in-flight messages) specified by the `QueueURL` parameter.
+     *
+     * ! When you use the `PurgeQueue` action, you can't retrieve any messages deleted from a queue.
+     * !
+     * ! The message deletion process takes up to 60 seconds. We recommend waiting for 60 seconds regardless of your queue's
+     * ! size.
+     *
+     * Messages sent to the queue *before* you call `PurgeQueue` might be received but are deleted within the next minute.
+     *
+     * Messages sent to the queue *after* you call `PurgeQueue` might be deleted while the queue is being purged.
      *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_PurgeQueue.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#purgequeue
      *
      * @param array{
      *   QueueUrl: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|PurgeQueueRequest $input
      *
      * @throws QueueDoesNotExistException
@@ -328,7 +459,7 @@ class SqsClient extends AbstractApi
      * @param array{
      *   QueueName: string,
      *   QueueOwnerAWSAccountId?: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|GetQueueUrlRequest $input
      */
     public function queueExists($input): QueueExistsWaiter
@@ -343,21 +474,55 @@ class SqsClient extends AbstractApi
 
     /**
      * Retrieves one or more messages (up to 10), from the specified queue. Using the `WaitTimeSeconds` parameter enables
-     * long-poll support. For more information, see Amazon SQS Long Polling in the *Amazon SQS Developer Guide*.
+     * long-poll support. For more information, see Amazon SQS Long Polling [^1] in the *Amazon SQS Developer Guide*.
+     *
+     * Short poll is the default behavior where a weighted random set of machines is sampled on a `ReceiveMessage` call.
+     * Thus, only the messages on the sampled machines are returned. If the number of messages in the queue is small (fewer
+     * than 1,000), you most likely get fewer messages than you requested per `ReceiveMessage` call. If the number of
+     * messages in the queue is extremely small, you might not receive any messages in a particular `ReceiveMessage`
+     * response. If this happens, repeat the request.
+     *
+     * For each message returned, the response includes the following:
+     *
+     * - The message body.
+     * - An MD5 digest of the message body. For information about MD5, see RFC1321 [^2].
+     * - The `MessageId` you received when you sent the message to the queue.
+     * - The receipt handle.
+     * - The message attributes.
+     * - An MD5 digest of the message attributes.
+     *
+     * The receipt handle is the identifier you must provide when deleting the message. For more information, see Queue and
+     * Message Identifiers [^3] in the *Amazon SQS Developer Guide*.
+     *
+     * You can provide the `VisibilityTimeout` parameter in your request. The parameter is applied to the messages that
+     * Amazon SQS returns in the response. If you don't include the parameter, the overall visibility timeout for the queue
+     * is used for the returned messages. For more information, see Visibility Timeout [^4] in the *Amazon SQS Developer
+     * Guide*.
+     *
+     * A message that isn't deleted or a message whose visibility isn't extended before the visibility timeout expires
+     * counts as a failed receive. Depending on the configuration of the queue, the message might be sent to the dead-letter
+     * queue.
+     *
+     * > In the future, new attributes might be added. If you write code that calls this action, we recommend that you
+     * > structure your code so that it can handle new attributes gracefully.
+     *
+     * [^1]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-long-polling.html
+     * [^2]: https://www.ietf.org/rfc/rfc1321.txt
+     * [^3]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-queue-message-identifiers.html
+     * [^4]: https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-visibility-timeout.html
      *
-     * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-long-polling.html
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ReceiveMessage.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#receivemessage
      *
      * @param array{
      *   QueueUrl: string,
-     *   AttributeNames?: list<MessageSystemAttributeName::*>,
+     *   AttributeNames?: array<MessageSystemAttributeName::*>,
      *   MessageAttributeNames?: string[],
      *   MaxNumberOfMessages?: int,
      *   VisibilityTimeout?: int,
      *   WaitTimeSeconds?: int,
      *   ReceiveRequestAttemptId?: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|ReceiveMessageRequest $input
      *
      * @throws OverLimitException
@@ -375,6 +540,15 @@ class SqsClient extends AbstractApi
     /**
      * Delivers a message to the specified queue.
      *
+     * ! A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:
+     * !
+     * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
+     * !
+     * ! Any characters not included in this list will be rejected. For more information, see the W3C specification for
+     * ! characters [^1].
+     *
+     * [^1]: http://www.w3.org/TR/REC-xml/#charsets
+     *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessage.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#sendmessage
      *
@@ -382,11 +556,11 @@ class SqsClient extends AbstractApi
      *   QueueUrl: string,
      *   MessageBody: string,
      *   DelaySeconds?: int,
-     *   MessageAttributes?: array<string, MessageAttributeValue>,
-     *   MessageSystemAttributes?: array<MessageSystemAttributeNameForSends::*, MessageSystemAttributeValue>,
+     *   MessageAttributes?: array<string, MessageAttributeValue|array>,
+     *   MessageSystemAttributes?: array<MessageSystemAttributeNameForSends::*, MessageSystemAttributeValue|array>,
      *   MessageDeduplicationId?: string,
      *   MessageGroupId?: string,
-     *   @region?: string,
+     *   '@region'?: string|null,
      * }|SendMessageRequest $input
      *
      * @throws InvalidMessageContentsException
@@ -404,16 +578,35 @@ class SqsClient extends AbstractApi
     }
 
     /**
-     * Delivers up to ten messages to the specified queue. This is a batch version of `SendMessage.` For a FIFO queue,
-     * multiple messages within a single batch are enqueued in the order they are sent.
+     * You can use `SendMessageBatch` to send up to 10 messages to the specified queue by assigning either identical or
+     * different values to each message (or by not assigning values at all). This is a batch version of `SendMessage.` For a
+     * FIFO queue, multiple messages within a single batch are enqueued in the order they are sent.
+     *
+     * The result of sending each message is reported individually in the response. Because the batch request can result in
+     * a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an
+     * HTTP status code of `200`.
+     *
+     * The maximum allowed individual message size and the maximum total payload size (the sum of the individual lengths of
+     * all of the batched messages) are both 256 KiB (262,144 bytes).
+     *
+     * ! A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:
+     * !
+     * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
+     * !
+     * ! Any characters not included in this list will be rejected. For more information, see the W3C specification for
+     * ! characters [^1].
+     *
+     * If you don't specify the `DelaySeconds` parameter for an entry, Amazon SQS uses the default value for the queue.
+     *
+     * [^1]: http://www.w3.org/TR/REC-xml/#charsets
      *
      * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessageBatch.html
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sqs-2012-11-05.html#sendmessagebatch
      *
      * @param array{
      *   QueueUrl: string,
-     *   Entries: SendMessageBatchRequestEntry[],
-     *   @region?: string,
+     *   Entries: array<SendMessageBatchRequestEntry|array>,
+     *   '@region'?: string|null,
      * }|SendMessageBatchRequest $input
      *
      * @throws TooManyEntriesInBatchRequestException
@@ -458,20 +651,6 @@ class SqsClient extends AbstractApi
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-iso-west-1':
-                return [
-                    'endpoint' => "https://sqs.$region.c2s.ic.gov",
-                    'signRegion' => $region,
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-isob-east-1':
-                return [
-                    'endpoint' => "https://sqs.$region.sc2s.sgov.gov",
-                    'signRegion' => $region,
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
             case 'fips-us-east-1':
                 return [
                     'endpoint' => 'https://sqs-fips.us-east-1.amazonaws.com',
@@ -500,52 +679,18 @@ class SqsClient extends AbstractApi
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-east-1':
-                return [
-                    'endpoint' => 'https://sqs.us-east-1.amazonaws.com',
-                    'signRegion' => 'us-east-1',
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-east-2':
-                return [
-                    'endpoint' => 'https://sqs.us-east-2.amazonaws.com',
-                    'signRegion' => 'us-east-2',
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-gov-east-1':
-                return [
-                    'endpoint' => 'https://sqs.us-gov-east-1.amazonaws.com',
-                    'signRegion' => 'us-gov-east-1',
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-gov-west-1':
-                return [
-                    'endpoint' => 'https://sqs.us-gov-west-1.amazonaws.com',
-                    'signRegion' => 'us-gov-west-1',
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
             case 'us-iso-east-1':
+            case 'us-iso-west-1':
                 return [
-                    'endpoint' => 'https://sqs.us-iso-east-1.c2s.ic.gov',
-                    'signRegion' => 'us-iso-east-1',
+                    'endpoint' => "https://sqs.$region.c2s.ic.gov",
+                    'signRegion' => $region,
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-west-1':
+            case 'us-isob-east-1':
                 return [
-                    'endpoint' => 'https://sqs.us-west-1.amazonaws.com',
-                    'signRegion' => 'us-west-1',
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-west-2':
-                return [
-                    'endpoint' => 'https://sqs.us-west-2.amazonaws.com',
-                    'signRegion' => 'us-west-2',
+                    'endpoint' => 'https://sqs.us-isob-east-1.sc2s.sgov.gov',
+                    'signRegion' => 'us-isob-east-1',
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
